@@ -6,7 +6,7 @@ use Mojo::Util qw(dumper);
 use DBI;
 use Carp qw(croak);
 
-our $VERSION  = '0.14';
+our $VERSION  = '0.15';
 
 use MojoX::Mysql::DB;
 use MojoX::Mysql::Result;
@@ -275,6 +275,10 @@ Return id servers in L<Mojo::Collection> object.
 
 SEE ALSO L<Mojolicious::Plugin::Mysql>
 
+=head1 Mojolicious migration
+
+SEE ALSO L<Mojolicious::Command::sql>
+
 =head1 AUTHOR
 
 Kostya Ten, C<kostya@cpan.org>.
